# Hunter's Hit Sounds Addon
#  
# Install instructions:
#       1. Install Mattie's EventScripts 2.1 plugin:
#           http://mattie.info/cs/
#
#       2. Copy and upload this script to:
#           <gamedir>/addons/eventscripts/hit_sounds/
#
#       3. Add the following line somewhere in autoexec.cfg:
#           es_load hit_sounds
#
################################################################################
#import EventScripts
import es
#import Libraries
import gamethread
import settinglib
import cfglib
import cmdlib

# Addon Information
info = es.AddonInfo()
info.name           = "Hit Sounds"
info.version        = "3.0.1"
info.author         = "Hunter"
info.url            = "http://addons.eventscripts.com/addons/user/289"
info.description    = "This scriptaddon adds hitsounds to your server"
info.basename       = "hit_sounds"

hunter_hit_sounds_ver   = info.version
hunter_hit_sounds_text  = 'Hunters '+info.name+', www.sourceplugins.de, '+info.version+', ES 2.1.1.338+'

# Server Variables
hit_sounds_config       = cfglib.AddonCFG('%s/hit_sounds.cfg' % es.getAddonPath('hit_sounds'))
hit_sounds_savetime     = hit_sounds_config.cvar('hit_sounds_savetime', 30, 'How much days should inactive users be stored, before their settings get deleted? ( default = 30 )')
hit_sounds_soundload    = hit_sounds_config.cvar('hit_sounds_soundload', 1, 'Should the sounds be downloaded with EventScripts?')
hit_sounds_default      = hit_sounds_config.cvar('hit_sounds_default', 1, 'Default settings for new connecting players')
hit_sounds_config.write()

# Settinglib Object
hit_sounds_setting      = settinglib.create('hitsounds', 'Hit Sounds', 'toggle')

def load():
    public = es.ServerVar('hu_hs', info.version, info.name)
    public.makepublic()
    
    cmdlib.registerSayCommand('!hitsounds', _say_cmd, 'Hit Sounds')

    hit_sounds_config.execute()
    hit_sounds_setting.addoption('headshot', 'Headshot Sound')
    hit_sounds_setting.addoption('teammate', 'Teammate Sound')
    hit_sounds_setting.addoption('normal', 'Normal Sound')
    hit_sounds_setting.setdefault('headshot', int(hit_sounds_default))
    hit_sounds_setting.setdefault('teammate', int(hit_sounds_default))
    hit_sounds_setting.setdefault('normal', int(hit_sounds_default))
    hit_sounds_setting.addsound('ui/buttonclick.wav')

    es.log(hunter_hit_sounds_text)
    es.msg('#multi', '#green[HitSounds] #defaultLoaded')
    
def unload():
    cmdlib.unregisterSayCommand('!hitsounds')
    
    es.msg('#multi', '#green[HitSounds] #defaultUnloaded')
    
def es_map_start(event_var):
    hit_sounds_setting.clear(int(hit_sounds_savetime)*86400)
    if int(hit_sounds_soundload):
        es.stringtable('downloadables', 'sound/player/hitsounds/headshot.wav')
        es.stringtable('downloadables', 'sound/player/hitsounds/hit.wav')
        es.stringtable('downloadables', 'sound/player/hitsounds/hitteammate.wav')

def es_client_command(event_var):
    if (str(event_var['command']) == '!hunter_hit_sounds_ver') or (str(event_var['command']) == '!hunter_all_ver'):
        es.cexec(int(event_var['userid']), 'echo '+hunter_hit_sounds_text)

def player_activate(event_var):
    hit_sounds_setting.updateTime(int(event_var['userid']))
    gamethread.delayed(30, es.cexec, (int(event_var['userid']), 'echo '+hunter_hit_sounds_text))
    gamethread.delayed(15, es.tell, (int(event_var['userid']), '#multi', '#green[HitSounds] #defaultSay \'!hitsounds\' for settings menu'))

def player_disconnect(event_var):
    hit_sounds_setting.updateTime(int(event_var['userid']))

def player_hurt(event_var):
    userid = int(event_var['userid'])
    attacker = int(event_var['attacker'])
    if attacker and es.exists('userid', attacker) and not es.isbot(attacker):
        if int(event_var['es_userteam']) == int(event_var['es_attackerteam']):
            if userid != attacker and hit_sounds_setting.get('teammate', attacker):
                es.playsound(attacker, 'player/hitsounds/hitteammate.wav', 1.0)
        elif int(event_var['hitgroup']) == 1:
            if hit_sounds_setting.get('headshot', attacker):
                es.playsound(attacker, 'player/hitsounds/headshot.wav', 1.0)
        else:
            if hit_sounds_setting.get('normal', attacker):
                es.playsound(attacker, 'player/hitsounds/hit.wav', 1.0)

def _say_cmd(userid, args):
    hit_sounds_setting.send(userid)
